@@ -64,17 +64,10 @@ unicode_start_stop()
 	[ -x /usr/bin/unicode_start ] || [ -x /bin/unicode_start ] ||  return
 	[ -x /usr/bin/unicode_stop ] || [ -x /bin/unicode_stop ] || return
 
-	ENV_FILE="none"
+	ENV_FILE=""
 	[ -r /etc/environment ] && ENV_FILE="/etc/environment"
 	[ -r /etc/default/locale ] && ENV_FILE="/etc/default/locale" 
-	[ $ENV_FILE = none ] && return
-	
-	for var in LANG LC_ALL LC_CTYPE; do
-		value=$(egrep "^[^#]*${var}=" $ENV_FILE | tail -n1 | cut -d= -f2)
-		eval $var=$value
-	done
-
-	CHARMAP=$(set -a && . "$ENV_FILE" && locale charmap)
+	[ "$ENV_FILE" ] && CHARMAP=$(set -a && . "$ENV_FILE" && locale charmap)
 	if [ "$CHARMAP" = "UTF-8" ]; then
 		unicode_start 2> /dev/null || true
 	else
